@@ -147,13 +147,10 @@ static gboolean
 brasero_burn_dialog_notify_daemon (BraseroBurnDialog *dialog,
                                    const char *message)
 {
-	BraseroBurnDialogPrivate *priv;
         NotifyNotification *notification;
 	GError *error = NULL;
         gboolean result;
 
-	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
-
 	if (!notify_is_initted ()) {
 		notify_init (_("Brasero notification"));
 	}
@@ -1020,13 +1017,12 @@ brasero_burn_dialog_eject_failure_cb (BraseroBurn *burn,
 	gchar *name;
 	gchar *string;
 	gint removal_id;
-	GtkWindow *window;
 	GtkWidget *message;
 	gboolean hide = FALSE;
 	BraseroBurnDialogPrivate *priv;
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
-
+	
 	if (!gtk_widget_get_visible (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
@@ -1034,8 +1030,6 @@ brasero_burn_dialog_eject_failure_cb (BraseroBurn *burn,
 
 	g_timer_stop (priv->total_time);
 
-	window = GTK_WINDOW (dialog);
-
 	name = brasero_drive_get_display_name (drive);
 	/* Translators: %s is the name of a drive */
 	string = g_strdup_printf (_("Please eject the disc from \"%s\" manually."), name);
@@ -1155,16 +1149,10 @@ brasero_burn_dialog_update_title_writing_progress (BraseroBurnDialog *dialog,
 						   BraseroMedia media,
 						   guint percent)
 {
-	BraseroBurnDialogPrivate *priv;
-	BraseroBurnFlag flags;
 	gchar *title = NULL;
 	gchar *icon_name;
 	guint remains;
 
-	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
-
-	flags = brasero_burn_session_get_flags (priv->session);
-
 	/* This is used only when actually writing to a disc */
 	if (media == BRASERO_MEDIUM_FILE)
 		title = brasero_burn_dialog_create_dialog_title_for_action (dialog,
@@ -2549,11 +2537,11 @@ brasero_burn_dialog_init (BraseroBurnDialog * obj)
 			    TRUE,
 			    0);
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox);
 	gtk_container_add (GTK_CONTAINER (alignment), vbox);
 
-	box = gtk_hbox_new (FALSE, 0);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show (box);
 	gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, TRUE, 0);
 
