@@ -98,7 +98,7 @@ brasero_burn_progress_get_type ()
 			(GInstanceInitFunc)brasero_burn_progress_init,
 		};
 
-		type = g_type_register_static(GTK_TYPE_VBOX, 
+		type = g_type_register_static(GTK_TYPE_BOX, 
 					      "BraseroBurnProgress",
 					      &our_info,
 					      0);
@@ -244,7 +244,7 @@ brasero_burn_progress_display_session_info (BraseroBurnProgress *obj,
 		gtk_widget_show_all (table);
 	}
 
-	text = g_format_size_for_display (written);
+	text = g_format_size (written);
 	markup = g_strconcat ("<i>", text, "</i>", NULL);
 	g_free (text);
 
@@ -307,14 +307,15 @@ brasero_burn_progress_init (BraseroBurnProgress *obj)
 
 	obj->priv = g_new0 (BraseroBurnProgressPrivate, 1);
 	gtk_box_set_spacing (GTK_BOX (obj), 2);
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (obj), GTK_ORIENTATION_VERTICAL);
 
-	box = gtk_hbox_new (FALSE, 0);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	obj->priv->progress = gtk_progress_bar_new ();
 	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (obj->priv->progress), " ");
 	gtk_box_pack_start (GTK_BOX (box), obj->priv->progress, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (obj), box, TRUE, TRUE, 2);
 
-	box = gtk_hbox_new (FALSE, 24);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 24);
 	gtk_box_pack_start (GTK_BOX (obj), box, FALSE, FALSE, 0);
 
 	obj->priv->action = gtk_label_new (NULL);
