@@ -80,7 +80,19 @@ enum {
 	NUM_COL
 };
 
-G_DEFINE_TYPE (BraseroMediumSelection, brasero_medium_selection, GTK_TYPE_COMBO_BOX);
+/* GtkBuildable */
+static GtkBuildableIface *parent_buildable_iface;
+
+static void
+brasero_medium_selection_buildable_init (GtkBuildableIface *iface)
+{
+	parent_buildable_iface = g_type_interface_peek_parent (iface);
+} 
+
+G_DEFINE_TYPE_WITH_CODE (BraseroMediumSelection,
+                         brasero_medium_selection,
+                         GTK_TYPE_COMBO_BOX,
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE, brasero_medium_selection_buildable_init));
 
 void
 brasero_medium_selection_foreach (BraseroMediumSelection *selection,
@@ -155,7 +167,7 @@ brasero_medium_selection_get_medium_string (BraseroMediumSelection *self,
 
 	/* format the size */
 	if (media & BRASERO_MEDIUM_HAS_DATA) {
-		size_string = g_format_size_for_display (size);
+		size_string = g_format_size (size);
 		/* NOTE for translators: the first %s is the medium name, the
 		 * second %s is the space (kio, gio) used by data on the disc.
 		 */
@@ -187,12 +199,9 @@ brasero_medium_selection_update_used_space (BraseroMediumSelection *selector,
 					    BraseroMedium *medium_arg,
 					    guint used_space)
 {
-	BraseroMediumSelectionPrivate *priv;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (selector);
-
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (selector));
 	if (!gtk_tree_model_get_iter_first (model, &iter))
 		return;
@@ -224,9 +233,6 @@ static void
 brasero_medium_selection_set_show_used_space (BraseroMediumSelection *selector)
 {
 	GtkCellRenderer *renderer;
-	BraseroMediumSelectionPrivate *priv;
-
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (selector);
 
 	gtk_cell_layout_clear (GTK_CELL_LAYOUT (selector));
 
@@ -260,9 +266,7 @@ brasero_medium_selection_update_media_string (BraseroMediumSelection *self)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	gboolean valid;
 
-	valid = FALSE;
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
 	if (!gtk_tree_model_get_iter_first (model, &iter))
 		return;
@@ -329,12 +333,9 @@ brasero_medium_selection_set_current_medium (BraseroMediumSelection *self,
 static void
 brasero_drive_selection_set_tooltip (BraseroMediumSelection *self)
 {
-	BraseroMediumSelectionPrivate *priv;
 	BraseroMedium *medium;
 	gchar *tooltip;
 
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (self);
-
 	medium = brasero_medium_selection_get_active (self);
 	if (medium) {
 		tooltip = brasero_medium_get_tooltip (medium);
@@ -350,10 +351,8 @@ brasero_drive_selection_set_tooltip (BraseroMediumSelection *self)
 static void
 brasero_medium_selection_changed (GtkComboBox *combo)
 {
-	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	model = gtk_combo_box_get_model (combo);
 	if (!gtk_combo_box_get_active_iter (combo, &iter))
 		return;
 
@@ -383,7 +382,6 @@ brasero_medium_selection_set_active (BraseroMediumSelection *selector,
 	g_return_val_if_fail (BRASERO_IS_MEDIUM_SELECTION (selector), FALSE);
 
 	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (selector);
-
 	if (priv->active == medium)
 		return TRUE;
 
@@ -427,7 +425,7 @@ BraseroMedium *
 brasero_medium_selection_get_active (BraseroMediumSelection *selector)
 {
 	BraseroMediumSelectionPrivate *priv;
-
+	
 	g_return_val_if_fail (selector != NULL, NULL);
 	g_return_val_if_fail (BRASERO_IS_MEDIUM_SELECTION (selector), NULL);
 
@@ -478,9 +476,6 @@ brasero_medium_selection_add_no_disc_entry (BraseroMediumSelection *self)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
-	BraseroMediumSelectionPrivate *priv;
-
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (self);
 
 	/* Nothing's available. Say it. Two cases here, either we're
 	 * still probing drives or there isn't actually any available
@@ -647,6 +642,24 @@ brasero_medium_selection_medium_added_cb (BraseroMediumMonitor *monitor,
 
 	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (self);
 
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
+
+	/* Make sure it's not already in our list */
+	if (gtk_tree_model_get_iter_first (model, &iter)) {
+		do {
+			BraseroMedium *tmp;
+
+			tmp = NULL;
+			gtk_tree_model_get (model, &iter,
+					    MEDIUM_COL, &tmp,
+					    -1);
+			if (tmp == medium)
+				return;
+
+		} while (gtk_tree_model_iter_next (model, &iter));
+	}
+
+	/* Make sure it does fit the types of media to display */
 	drive = brasero_medium_get_drive (medium);
 	if ((priv->type & BRASERO_MEDIA_TYPE_CD) == priv->type
 	&& (brasero_medium_get_status (medium) & BRASERO_MEDIUM_CD))
@@ -704,8 +717,6 @@ brasero_medium_selection_medium_added_cb (BraseroMediumMonitor *monitor,
 		}
 	}
 
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
-
 	if (!add) {
 		BraseroMedium *tmp;
 
@@ -807,6 +818,12 @@ brasero_medium_selection_medium_removed_cb (BraseroMediumMonitor *monitor,
 	}
 }
 
+static void
+brasero_medium_selection_constructed (GObject *object)
+{
+	brasero_medium_selection_set_show_used_space (BRASERO_MEDIUM_SELECTION (object));
+}
+
 static void
 brasero_medium_selection_init (BraseroMediumSelection *object)
 {
@@ -825,7 +842,6 @@ brasero_medium_selection_init (BraseroMediumSelection *object)
 					      "medium-removed",
 					      G_CALLBACK (brasero_medium_selection_medium_removed_cb),
 					      object);
-
 	g_object_unref (monitor);
 
 	/* get the list and fill the model */
@@ -839,8 +855,6 @@ brasero_medium_selection_init (BraseroMediumSelection *object)
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (object), GTK_TREE_MODEL (model));
 	g_object_unref (model);
-
-	brasero_medium_selection_set_show_used_space (object);
 }
 
 static void
@@ -869,12 +883,8 @@ brasero_medium_selection_set_property (GObject *object,
 				       const GValue *value,
 				       GParamSpec *pspec)
 {
-	BraseroMediumSelectionPrivate *priv;
-
 	g_return_if_fail (BRASERO_IS_MEDIUM_SELECTION (object));
 
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (object);
-
 	switch (prop_id)
 	{
 	case PROP_MEDIA_TYPE:
@@ -925,6 +935,7 @@ brasero_medium_selection_class_init (BraseroMediumSelectionClass *klass)
 
 	g_type_class_add_private (klass, sizeof (BraseroMediumSelectionPrivate));
 
+	object_class->constructed = brasero_medium_selection_constructed;
 	object_class->finalize = brasero_medium_selection_finalize;
 	object_class->set_property = brasero_medium_selection_set_property;
 	object_class->get_property = brasero_medium_selection_get_property;
