@@ -52,10 +52,6 @@
 #include "brasero-uri-container.h"
 #include "brasero-project-type-chooser.h"
 
-#ifdef BUILD_SEARCH
-#include "brasero-search.h"
-#endif
-
 #ifdef BUILD_PLAYLIST
 #include "brasero-playlist.h"
 #endif
@@ -254,7 +250,7 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 		||  manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO)
 			size_string = brasero_units_get_time_string (files_size, TRUE, FALSE);
 		else if (manager->priv->type == BRASERO_PROJECT_TYPE_DATA)
-			size_string = g_format_size_for_display (files_size);
+			size_string = g_format_size (files_size);
 		else
 			return;
 
@@ -276,7 +272,7 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 							 size_string);
 		}
 		else if (manager->priv->type == BRASERO_PROJECT_TYPE_DATA) {
-			size_string = g_format_size_for_display (files_size);
+			size_string = g_format_size (files_size);
 			status_string = g_strdup_printf (ngettext ("%d file can be added (%s)", "%d selected files can be added (%s)", valid_num),
 							 valid_num,
 							 size_string);
@@ -899,27 +895,6 @@ brasero_project_manager_init (BraseroProjectManager *obj)
 				    obj->priv->project);
 	gtk_widget_show (obj->priv->project);
 
-#ifdef BUILD_SEARCH
-	GtkWidget *search;
-
-	search = brasero_search_new ();
-    	BRASERO_PROJECT_MANAGER_CONNECT_CHANGED (obj, search);
-
-	gtk_widget_show_all (search);
-	brasero_layout_add_source (BRASERO_LAYOUT (obj->priv->layout),
-				   search,
-				   "Search",
-				   _("Search files using keywords"),
-				   GTK_STOCK_FIND,
-				   BRASERO_LAYOUT_AUDIO|BRASERO_LAYOUT_DATA|BRASERO_LAYOUT_VIDEO);
-
-#ifdef BUILD_PREVIEW
-	brasero_preview_add_source (BRASERO_PREVIEW (preview),
-				    BRASERO_URI_CONTAINER (search));
-#endif
-
-#endif /* BUILD_SEARCH */
-
 #ifdef BUILD_PLAYLIST
 	GtkWidget *playlist;
 
